RestApiClientKeys class

Constructors

RestApiClientKeys()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

acceptLanguage → const String
The HTTP header key used to specify the language preference of the client.
authorization → const String
The HTTP header key for authorization tokens.
cachedStorageKey → const String
Key used for caching data in the repository for the REST API client.
contentType → const String
The HTTP header key used to specify the media type of the resource, typically 'application/json' or 'application/xml'.
jwt → const String
Key used to store the JSON Web Token (JWT) required for authorization.
refreshToken → const String
Key used to store the refresh token which can be used to obtain a new JWT.
storageKey → const String
Key used for the primary storage repository for the REST API client.