init method
Initializes the auth handler and restores any previously stored tokens.
After initialization, if a valid JWT exists in storage, it will be set to the Authorization header automatically.
Implementation
Future init() async {
await _storage.init();
if (loggingOptions.logStorage) {
await _storage.log();
}
final currentJwt = await jwt;
if (currentJwt != null && currentJwt.isNotEmpty) {
_setJwtToHeader(currentJwt);
}
}